@@ -1,48 +1,42 @@
 context("indices")
 
-invisible(tryCatch(elastic::connect(), error = function(e) e))
+invisible(connect())
 
 test_that("index_get", {
-  skip_on_cran()
-
-  a <- index_get(index = 'shakespeare')
-  expect_equal(names(a), "shakespeare")
-  expect_is(a, "list")
-  expect_is(a$shakespeare, "list")
-  expect_equal(length(a$shakespeare$aliases), 0)
-  expect_error(index_get("adfadfadsfasdfadfasdfsf"), "missing")
+  if (!es_version() < 120) {
+    a <- index_get(index = 'shakespeare')
+    expect_equal(names(a), "shakespeare")
+    expect_is(a, "list")
+    expect_is(a$shakespeare, "list")
+    expect_equal(length(a$shakespeare$aliases), 0)
+    expect_error(index_get("adfadfadsfasdfadfasdfsf"), 'no such index||IndexMissingException')
+  }
 })
 
 test_that("index_exists", {
-  skip_on_cran()
-
   expect_true(index_exists(index = 'shakespeare'))
   expect_false(index_exists(index = 'asdfasdfadfasdfasfasdf'))
 })
 
 test_that("index_create", {
-  skip_on_cran()
-
   ind <- "stuff_yy"
   invisible(tryCatch(index_delete(index = ind, verbose = FALSE), error = function(e) e))
   a <- index_create(index = ind, verbose = FALSE)
   expect_true(a[[1]])
   expect_named(a, expected = "acknowledged")
   expect_is(a, "list")
-  expect_error(index_create("/"), "Bad Request")
+  expect_error(index_create("/"), "Invalid index name")
 })
 
 test_that("index_delete", {
-  skip_on_cran()
-
   nm <- "stuff_zz"
-  tryCatch(index_delete(index = nm, verbose = FALSE), error = function(e) e)
+  invisible(tryCatch(index_delete(index = nm, verbose = FALSE), error = function(e) e))
   a <- index_create(index = nm, verbose = FALSE)
   b <- index_delete(nm, verbose = FALSE)
   expect_true(b[[1]])
   expect_named(b, expected = "acknowledged")
   expect_is(b, "list")
-  expect_error(index_delete("adfadfafafasdfasdfasfasfasfd"), "Not Found")
+  expect_error(index_delete("adfadfafafasdfasdfasfasfasfd", verbose=FALSE), "no such index||IndexMissingException")
 })
 
 # test_that("index_close, index_open", {
@@ -56,45 +50,29 @@ test_that("index_delete", {
 #   expect_error(index_open("adfadfafafasdfasdfasfasfasfd"), "Not Found")
 # })
 
-test_that("index_status", {
-  skip_on_cran()
-
-  a <- index_status('shakespeare')
-  expect_is(a, "list")
-  expect_named(a$indices, "shakespeare")
-  expect_error(index_status("adfadfafafasdfasdfasfasfasfd"), "missing")
-})
-
 test_that("index_stats", {
-  skip_on_cran()
-
   a <- index_stats('shakespeare')
   expect_is(a, "list")
   expect_named(a$indices, "shakespeare")
-  expect_error(index_stats("adfadfafafasdfasdfasfasfasfd"), "missing")
+  expect_error(index_stats("adfadfafafasdfasdfasfasfasfd", verbose=FALSE), "no such index||IndexMissingException")
 })
 
 test_that("index_segments", {
-  skip_on_cran()
-
   a <- index_segments('shakespeare')
   expect_is(a, "list")
   expect_named(a$indices, "shakespeare")
-  expect_error(index_segments("adfadfafafasdfasdfasfasfasfd"), "missing")
+  expect_error(index_segments("adfadfafafasdfasdfasfasfasfd", verbose=FALSE), "no such index||IndexMissingException")
 })
 
 test_that("index_recovery", {
-  skip_on_cran()
-
-  a <- index_recovery('shakespeare')
-  expect_is(a, "list")
-  expect_named(a$shakespeare, "shards")
-  expect_error(index_recovery("adfadfafafasdfasdfasfasfasfd"), "missing")
+  if (!es_version() < 110) {
+    a <- index_recovery('shakespeare')
+    expect_is(a, "list")
+    expect_named(a$shakespeare, "shards")
+    expect_error(index_recovery("adfadfafafasdfasdfasfasfasfd", verbose=FALSE), "no such index||IndexMissingException")
+  }
 })
 
 ## cleanup -----------------------------------
-tryconnect = tryCatch(elastic::connect(), error = function(e) e)
-if (!is(tryconnect, "simpleError")) {
-  invisible(index_delete("stuff_yy", verbose = FALSE))
-}
+invisible(index_delete("stuff_yy", verbose = FALSE))
 # invisible(index_delete('test_close_open', verbose = FALSE))
